#!/system/bin/sh
TAG="InitVariant"
DEVICE_DIR="/vendor/device"
DEVICE_VARIANT_FILE="$DEVICE_DIR/variant"
DEVICE_VARIANT_PROP_FILE="$DEVICE_DIR/variant.prop"
VARIANT_DIR="/system/etc/variants"
VARIANT_EXT_DIR="$DEVICE_DIR/variants"

variant="default"

if [ -f $DEVICE_VARIANT_FILE ]; then
  active_variant=$(getprop persist.sys.variant)
  variant=$(cat $DEVICE_VARIANT_FILE)
  if [ ! -e $DEVICE_VARIANT_PROP_FILE ]; then
    echo "variant=$variant" > $DEVICE_VARIANT_PROP_FILE
    chmod 644 $DEVICE_VARIANT_PROP_FILE
  fi
  if [ ! "$active_variant" = "$variant" ]; then
    used_variant_dir=$VARIANT_DIR
    if [ -f "$VARIANT_EXT_DIR/$variant" ]; then
      cur_sw=$(getprop ro.build.fingerprint | busybox cut -d "/" -f 4 | busybox cut -d "-" -f 1)
      ext_sw=$(cat "$VARIANT_EXT_DIR/$variant" | busybox grep "SW_VERSION" | busybox cut -d "=" -f 2)
      [ "-$cur_sw-" = "-$ext_sw-" ] && used_variant_dir=$VARIANT_EXT_DIR
    fi
    if [ -f "$used_variant_dir/$variant" ]; then
      echo "variant=$variant" > $DEVICE_VARIANT_PROP_FILE
      chmod 644 $DEVICE_VARIANT_PROP_FILE
      sh "$used_variant_dir/$variant"
      setprop persist.sys.variant "$variant"
      sync
      log -t $TAG "Set variant = $variant (from $used_variant_dir)" 
      rm -f /cache/recovery/provision.zip
      rm -f /cache/provision.zip
    else
      log -t $TAG "File $used_variant_dir/$variant not found" 
    fi
  else
    log -t $TAG "Current variant = $active_variant" 
  fi
else
    log -t $TAG "Device variant file $DEVICE_VARIANT_FILE not found" 
    if [ -f /cache/provision.zip ]; then
      #Backup provision file
      mkdir -p /cache/recovery
      mv /cache/provision.zip /cache/recovery/provision.zip
    fi
fi
